==> guile2.0-2.0.14-1-aarch64.pkg.tar.xz: usr/lib/guile/2.0/ccache/srfi/srfi-4/gnu.go <==
GOOF----LE-8-2.04      ]  4 hF      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-4	g  gnu		 	
g  filenameS	f  srfi/srfi-4/gnu.scm	g  importsS	
g  rnrs	g  bytevectors	
 	 	 	 	 	g  exportsS	g  
c32vector?	g  make-c32vector	g  	c32vector	g  c32vector-length	g  
c32vector-ref	g  c32vector-set!	g  c32vector->list	g  list->c32vector	g  
c64vector?	g  make-c64vector	g  	c64vector	 g  c64vector-length	!g  
c64vector-ref	"g  c64vector-set!	#g  c64vector->list	$g  list->c64vector	%g  make-srfi-4-vector	&g  
any->u8vector	'g  
any->s8vector	(g  any->u16vector	)g  any->s16vector	*g  any->u32vector	+g  any->s32vector	,g  any->u64vector	-g  any->s64vector	.g  any->f32vector	/g  any->f64vector	0g  any->c32vector	1g  any->c64vector	2 !"#$%&'()*+,-./01 	3g  set-current-module	43 	53 	6% 	7% 	8g  make-rectangular	9g  bytevector-c32-native-ref	:g  	real-part	;g  	imag-part	<g  bytevector-c32-native-set!	=g  bytevector-c64-native-ref	>g  bytevector-c64-native-set!	?g  bytevector?	@g  
array-type	Ag  c32	Bg  bytevector-length	Cg  integer?	Dg  error	Ef  fractional length	Fg  length	Gg  c64	Hg  make-syntax-transformer	IH 	JH 	Kg  define-any->vector	Lg  macro	Mg  $sc-dispatch	NM 	OM 	Pg  _	Qg  any	RPQ	Sg  
syntax->datum	TS 	US 	Vg  
datum->syntax	WV 	XV 	Yg  begin	Zg  map	[g  define	\g  
symbol-append	]g  any->	^g  vector	_g  obj	`_ 	ag  cond	bg  vector?	cg  pair?	dc_ 	eg  list->	fg  and	gg  array?	hg_ 	ig  eqv?	jg  
array-rank	kj_ 	lik 	mfhl 	ng  let*	og  len	pg  array-length	qp_ 	roq 	sg  v	tg  make-	uo 	vg  let	wg  lp	xg  i	yx
 	zy 	{g  if	|g  <	}|xo 	~g  vector-set!	g  	array-ref _x  sx  g  1+ x  w    s  g  else g  	scm-error g  quote g  wrong-type-arg   f      g  list _        g  syntax-violation     f  -source expression failed to match any pattern g  	u8vector? g  list->u8vector g  
make-u8vector g  	s8vector? g  list->s8vector g  
make-s8vector g  
u16vector? g  list->u16vector g  make-u16vector g  
s16vector? g  list->s16vector g  make-s16vector g  
u32vector? g  list->u32vector g  make-u32vector g  
s32vector? g  list->s32vector g  make-s32vector g  
u64vector? g  list->u64vector g  make-u64vector g  
s64vector? g  list->s64vector g  make-s64vector g  
f32vector? g  list->f32vector g  make-f32vector g  
f64vector? g  list->f64vector g  make-f64vectorC 5     h '     ]4	
25 45 >  "  G   7%R8 h      ]  	6            g  v
		 g  i		  g  filenamef  srfi/srfi-4/gnu.scm
	,
			-			.	9		.			-	 			  g  nameg  bytevector-c32-native-ref C9R:;   h       ] 45 	45C        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	/
		0	*		0			1	(		1	0		1	 			  g  nameg  bytevector-c32-native-set! C<R8     h      ]  	6            g  v
		 g  i		  g  filenamef  srfi/srfi-4/gnu.scm
	2
			3			4	9		4			3	 			  g  nameg  bytevector-c64-native-ref C=R:;   h       ] 45 	45C        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	5
		6	*		6			7	(		7	0		7	 			  g  nameg  bytevector-c64-native-set! C>R?@A h    n   ]4 5$  4 5CC      f       g  obj
		  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		  g  nameg  
c32vector? CR%A       h      - 1 3  @     }       g  len
			 g  fill			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			
  g  nameg  make-c32vector CRBCDEA  h(      ]	4 5	45$  C 	6       g  v
		( g  len		(  g  filenamef  srfi/srfi-4/gnu.scm
	9
g  filenamef  7/build/guile2.0/src/guile-2.0.14/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c32vector-length CR     h   p   -  1  3  6 h       g  elts
			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			


  g  nameg  	c32vector CRF   h`      ]!4 545"  ;$  /$  %4>  "  G  "CC
 "         g  elts
		^ g  len			^ g  v			^ g  i			S g  elts			S  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		^  g  nameg  list->c32vector CR h@      ]"  "
$  C4 5"4 5"              g  v
		9 g  i		( g  elts			(  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		9  g  nameg  c32vector->list CR9      h   ~   ] 	6   v       g  v
		
 g  i		
  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		
	  g  nameg  
c32vector-ref CR< h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			  g  nameg  c32vector-set! CR< h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			  g  nameg  c32vector-set! CR?@G     h    n   ]4 5$  4 5CC      f       g  obj
		  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		  g  nameg  
c64vector? CR%G       h      - 1 3  @     }       g  len
			 g  fill			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			
  g  nameg  make-c64vector CRBCDEG  h(      ]	4 5	45$  C 	6       g  v
		( g  len		(  g  filenamef  srfi/srfi-4/gnu.scm
	:
g  filenamef  7/build/guile2.0/src/guile-2.0.14/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c64vector-length C R$     h   p   -  1  3  6 h       g  elts
			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			


  g  nameg  	c64vector CRF"   h`      ]!4 545"  ;$  /$  %4>  "  G  "CC
 "         g  elts
		^ g  len			^ g  v			^ g  i			S g  elts			S  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		^  g  nameg  list->c64vector C$R!  h@      ]"  "
$  C4 5"4 5"              g  v
		9 g  i		( g  elts			(  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		9  g  nameg  c64vector->list C#R=      h   ~   ] 	6   v       g  v
		
 g  i		
  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		
	  g  nameg  
c64vector-ref C!R> h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			  g  nameg  c64vector-set! C"R> h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			  g  nameg  c64vector-set! C"R4JKLORUXYZ[\]^`abdemnrstuvwz{}Y~ h     ]4 54 54	 5 

4 5  4 5    C        g  tag
	   g  filenamef  srfi/srfi-4/gnu.scm
	>			?			?				?	(	
	?	3		?			?			@			@	-		@			?		&	A	&	*	A	5	.	A	A	0	A	&	2	?		?	D	$	C	D	3	G	D	>	I	D	$	K	?		_	H	$	e	H	7	g	H	$	i	?	 	    C   h   r   -  1  3 4 5C  j       g  tags
			  g  filenamef  srfi/srfi-4/gnu.scm
	<
		=			>			=	 			


   C   h   g   ]	4 5L 4?6_       g  args
		 g  v			  g  filenamef  srfi/srfi-4/gnu.scm		<
 		   C  h(   e   ]	4 5$   O @ 6 ]       g  y
		' g  tmp		'  g  filenamef  srfi/srfi-4/gnu.scm
	<
 		'   C5KRgjp      h      ]4 5$   C $   6"    64 5$  P4 5&  @4 54	5"  #$  4
 5"C
"""        g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  
any->u8vector C&Rgjp h      ]4 5$   C $   6"    64 5$  P4 5&  @4 54	5"  #$  4
 5"C
"""        g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  
any->s8vector C'Rgjp h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->u16vector C(Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->s16vector C)Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->u32vector C*Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->s32vector C+Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->u64vector C,Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->s64vector C-Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->f32vector C.Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->f64vector C/Rgjp      h      ]4 5$   C $   6"    64 5$  _4 5&  O4 54	5"  2$  &4
4 5>  "  G  "C
"""         g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->c32vector C0R$gjp"      h      ]4 5$   C $   6"    64 5$  _4 5&  O4 54	5"  2$  &4
4 5>  "  G  "C
"""         g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->c64vector C1RC             g  m
		,  g  filenamef  srfi/srfi-4/gnu.scm		
	1	*
	,
	/
	2
	5
q	9
	:
/	O
 
	&
   C6 

==> guile-2.0.11-3-aarch64.pkg.tar.xz: usr/lib/guile/2.0/ccache/srfi/srfi-4/gnu.go <==
GOOF----LE-8-2.04      ]  4 hF      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-4	g  gnu		 	
g  filenameS	f  srfi/srfi-4/gnu.scm	g  importsS	
g  rnrs	g  bytevectors	
 	 	 	 	 	g  exportsS	g  
c32vector?	g  make-c32vector	g  	c32vector	g  c32vector-length	g  
c32vector-ref	g  c32vector-set!	g  c32vector->list	g  list->c32vector	g  
c64vector?	g  make-c64vector	g  	c64vector	 g  c64vector-length	!g  
c64vector-ref	"g  c64vector-set!	#g  c64vector->list	$g  list->c64vector	%g  make-srfi-4-vector	&g  
any->u8vector	'g  
any->s8vector	(g  any->u16vector	)g  any->s16vector	*g  any->u32vector	+g  any->s32vector	,g  any->u64vector	-g  any->s64vector	.g  any->f32vector	/g  any->f64vector	0g  any->c32vector	1g  any->c64vector	2 !"#$%&'()*+,-./01 	3g  set-current-module	43 	53 	6% 	7% 	8g  make-rectangular	9g  bytevector-c32-native-ref	:g  	real-part	;g  	imag-part	<g  bytevector-c32-native-set!	=g  bytevector-c64-native-ref	>g  bytevector-c64-native-set!	?g  bytevector?	@g  
array-type	Ag  c32	Bg  bytevector-length	Cg  integer?	Dg  error	Ef  fractional length	Fg  length	Gg  c64	Hg  make-syntax-transformer	IH 	JH 	Kg  define-any->vector	Lg  macro	Mg  $sc-dispatch	NM 	OM 	Pg  _	Qg  any	RPQ	Sg  
syntax->datum	TS 	US 	Vg  
datum->syntax	WV 	XV 	Yg  begin	Zg  map	[g  define	\g  
symbol-append	]g  any->	^g  vector	_g  obj	`_ 	ag  cond	bg  vector?	cg  pair?	dc_ 	eg  list->	fg  and	gg  array?	hg_ 	ig  eqv?	jg  
array-rank	kj_ 	lik 	mfhl 	ng  let*	og  len	pg  array-length	qp_ 	roq 	sg  v	tg  make-	uo 	vg  let	wg  lp	xg  i	yx
 	zy 	{g  if	|g  <	}|xo 	~g  vector-set!	g  	array-ref _x  sx  g  1+ x  w    s  g  else g  	scm-error g  quote g  wrong-type-arg   f      g  list _        g  syntax-violation     f  -source expression failed to match any pattern g  	u8vector? g  list->u8vector g  
make-u8vector g  	s8vector? g  list->s8vector g  
make-s8vector g  
u16vector? g  list->u16vector g  make-u16vector g  
s16vector? g  list->s16vector g  make-s16vector g  
u32vector? g  list->u32vector g  make-u32vector g  
s32vector? g  list->s32vector g  make-s32vector g  
u64vector? g  list->u64vector g  make-u64vector g  
s64vector? g  list->s64vector g  make-s64vector g  
f32vector? g  list->f32vector g  make-f32vector g  
f64vector? g  list->f64vector g  make-f64vectorC 5     h '     ]4	
25 45 >  "  G   7%R8 h      ]  	6            g  v
		 g  i		  g  filenamef  srfi/srfi-4/gnu.scm
	,
			-			.	9		.			-	 			  g  nameg  bytevector-c32-native-ref C9R:;   h       ] 45 	45C        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	/
		0	*		0			1	(		1	0		1	 			  g  nameg  bytevector-c32-native-set! C<R8     h      ]  	6            g  v
		 g  i		  g  filenamef  srfi/srfi-4/gnu.scm
	2
			3			4	9		4			3	 			  g  nameg  bytevector-c64-native-ref C=R:;   h       ] 45 	45C        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	5
		6	*		6			7	(		7	0		7	 			  g  nameg  bytevector-c64-native-set! C>R?@A h    n   ]4 5$  4 5CC      f       g  obj
		  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		  g  nameg  
c32vector? CR%A       h      - 1 3  @     }       g  len
			 g  fill			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			
  g  nameg  make-c32vector CRBCDEA  h(      ]	4 5	45$  C 	6       g  v
		( g  len		(  g  filenamef  srfi/srfi-4/gnu.scm
	9
g  filenamef  4/build/guile/src/guile-2.0.11/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c32vector-length CR        h   p   -  1  3  6 h       g  elts
			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			


  g  nameg  	c32vector CRF   h`      ]!4 545"  ;$  /$  %4>  "  G  "CC
 "         g  elts
		^ g  len			^ g  v			^ g  i			S g  elts			S  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		^  g  nameg  list->c32vector CR h@      ]"  "
$  C4 5"4 5"              g  v
		9 g  i		( g  elts			(  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		9  g  nameg  c32vector->list CR9      h   ~   ] 	6   v       g  v
		
 g  i		
  g  filenamef  srfi/srfi-4/gnu.scm
	9
 		
	  g  nameg  
c32vector-ref CR< h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			  g  nameg  c32vector-set! CR< h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	9
 			  g  nameg  c32vector-set! CR?@G     h    n   ]4 5$  4 5CC      f       g  obj
		  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		  g  nameg  
c64vector? CR%G       h      - 1 3  @     }       g  len
			 g  fill			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			
  g  nameg  make-c64vector CRBCDEG  h(      ]	4 5	45$  C 	6       g  v
		( g  len		(  g  filenamef  srfi/srfi-4/gnu.scm
	:
g  filenamef  4/build/guile/src/guile-2.0.11/module/srfi/srfi-4.scm	 	T	 		(  g  nameg  c64vector-length C R$        h   p   -  1  3  6 h       g  elts
			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			


  g  nameg  	c64vector CRF"   h`      ]!4 545"  ;$  /$  %4>  "  G  "CC
 "         g  elts
		^ g  len			^ g  v			^ g  i			S g  elts			S  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		^  g  nameg  list->c64vector C$R!  h@      ]"  "
$  C4 5"4 5"              g  v
		9 g  i		( g  elts			(  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		9  g  nameg  c64vector->list C#R=      h   ~   ] 	6   v       g  v
		
 g  i		
  g  filenamef  srfi/srfi-4/gnu.scm
	:
 		
	  g  nameg  
c64vector-ref C!R> h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			  g  nameg  c64vector-set! C"R> h      ] 	6        g  v
		 g  i		 g  x			  g  filenamef  srfi/srfi-4/gnu.scm
	:
 			  g  nameg  c64vector-set! C"R4JKLORUXYZ[\]^`abdemnrstuvwz{}Y~ h     ]4 54 54	 5 

4 5  4 5    C        g  tag
	   g  filenamef  srfi/srfi-4/gnu.scm
	>			?			?				?	(	
	?	3		?			?			@			@	-		@			?		&	A	&	*	A	5	.	A	A	0	A	&	2	?		?	D	$	C	D	3	G	D	>	I	D	$	K	?		_	H	$	e	H	7	g	H	$	i	?	 	    C   h   r   -  1  3 4 5C  j       g  tags
			  g  filenamef  srfi/srfi-4/gnu.scm
	<
		=			>			=	 			


   C   h   g   ]	4 5L 4?6_       g  args
		 g  v			  g  filenamef  srfi/srfi-4/gnu.scm		<
 		   C  h(   e   ]	4 5$   O @ 6 ]       g  y
		' g  tmp		'  g  filenamef  srfi/srfi-4/gnu.scm
	<
 		'   C5KRgjp      h      ]4 5$   C $   6"    64 5$  P4 5&  @4 54	5"  #$  4
 5"C
"""        g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  
any->u8vector C&Rgjp h      ]4 5$   C $   6"    64 5$  P4 5&  @4 54	5"  #$  4
 5"C
"""        g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  
any->s8vector C'Rgjp h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->u16vector C(Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->s16vector C)Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->u32vector C*Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->s32vector C+Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->u64vector C,Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->s64vector C-Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->f32vector C.Rgjp        h      ]4 5$   C $   6"    64 5$  S4 5&  C4 54	5"  &$  	4
 5"C
"""             g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->f64vector C/Rgjp      h      ]4 5$   C $   6"    64 5$  _4 5&  O4 54	5"  2$  &4
4 5>  "  G  "C
"""         g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->c32vector C0R$gjp"      h      ]4 5$   C $   6"    64 5$  _4 5&  O4 54	5"  2$  &4
4 5>  "  G  "C
"""         g  obj
	  g  len	N  g  v		W  g  i		]   g  filenamef  srfi/srfi-4/gnu.scm
	O
	(	L	; 	   g  nameg  any->c64vector C1RC             g  m
		,  g  filenamef  srfi/srfi-4/gnu.scm		
	1	*
	,
	/
	2
	5
q	9
	:
/	O
 
	&
   C6 
